@@ -198,7 +198,7 @@ class BaseObjectSerializer:
 
         elif isinstance(obj, dict):
             for k, v in obj.items():
-                if isinstance(v, PRIMITIVES):
+                if isinstance(v, PRIMITIVES) or v is None:
                     continue
                 else:
                     obj[k] = self.traverse_value(v)
@@ -213,10 +213,11 @@ class BaseObjectSerializer:
             try:
                 return obj.dict()
             except:
-                SerializationException(
-                    message=f"Failed to handle {type(obj)} in `BaseObjectSerializer.traverse_value`",
-                    object=obj,
+                warn(
+                    f"Failed to handle {type(obj)} in `BaseObjectSerializer.traverse_value`",
+                    SerializationException,
                 )
+
                 return str(obj)
 
     def detach_helper(self, ref_hash: str) -> Dict[str, str]:
